In perl.git, the branch blead has been updated

<http://perl5.git.perl.org/perl.git/commitdiff/f3e2e2629f0f71cdbc3fe0b9102a74a041e7919a?hp=2108cbcf2fd75bfcc7b9c01563db7063a67549cf>

- Log -----------------------------------------------------------------
commit f3e2e2629f0f71cdbc3fe0b9102a74a041e7919a
Author: Steve Hay <[email protected]>
Date:   Mon Jan 2 17:23:15 2017 +0000

    Update copyright year
-----------------------------------------------------------------------

Summary of changes:
 README | 2 +-
 perl.c | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/README b/README
index d46e72eda0..02ac59ca4c 100644
--- a/README
+++ b/README
@@ -1,6 +1,6 @@
 Perl is Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000,
 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012,
-2013, 2014, 2015, 2016 by Larry Wall and others.  All rights reserved.
+2013, 2014, 2015, 2016, 2017 by Larry Wall and others.  All rights reserved.
 
 
 
diff --git a/perl.c b/perl.c
index 9ba4ae0677..37335a4611 100644
--- a/perl.c
+++ b/perl.c
@@ -3,7 +3,7 @@
  *
  *    Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
  *    2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
  *    2013, 2014, 2015, 2016 by Larry Wall and others
  *
  *    You may distribute under the terms of either the GNU General Public
  *    License or the Artistic License, as specified in the README file.
@@ -3597,7 +3597,7 @@ S_minus_v(pTHX)
 #endif
 
        PerlIO_printf(PIO_stdout,
-                     "\n\nCopyright 1987-2016, Larry Wall\n");
+                     "\n\nCopyright 1987-2017, Larry Wall\n");
 #ifdef MSDOS
        PerlIO_printf(PIO_stdout,
                      "\nMS-DOS port Copyright (c) 1989, 1990, Diomidis 
@@ -3,7 +3,7 @@
  *    Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
  *    2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
- *    2013, 2014, 2015, 2016 by Larry Wall and others
+ *    2013, 2014, 2015, 2016, 2017 by Larry Wall and others
  *
  *    You may distribute under the terms of either the GNU General Public
Spinellis\n");

--
Perl5 Master Repository

Reply via email to